@@ -25,7 +25,7 @@ simple_rs <-
     
     if(check_inputs){
       
-      check_inputs <-
+      input_check <-
         check_samplr_arguments(N = N,
                                prob = prob)
     }
